import React from "react";
import { Tooltip, useTheme } from "@material-ui/core";
import {
  Brightness1,
  Cancel,
  Error,
  RadioButtonUnchecked,
  ErrorOutline,
  HelpOutline,
  PlayCircleFilled,
  PauseCircleFilled
} from "@material-ui/icons";

export function IOCStatusIcon({ ioc }) {
  const theme = useTheme();

  let { active, alert, alerts, activeDeployment } = ioc;

  const iconConfig = {
    active: {
      title: "Active",
      icon: <Brightness1 />
    },
    disabled: {
      title: "Disabled",
      icon: <Cancel />
    },
    alert: {
      title: "Alert",
      icon: <Error />
    },
    inactive: {
      title: "Inactive",
      icon: <RadioButtonUnchecked />
    },
    "inactive alert": {
      title: "Alert",
      icon: <ErrorOutline />
    },
    null: {
      title: "Unknown",
      icon: <HelpOutline />
    }
  };

  let status = null;

  if (active === null) active = undefined;
  if (typeof alerts === "object") alert = alerts?.[0]?.type;

  alert = alert?.toLowerCase();

  if (active && (alert === undefined || alert === "info")) {
    // Active status / running
    status = "active";
  } else if (active === false && (alert === undefined || alert === "info")) {
    // stopped/paused
    status = "disabled";
  } else if (active !== undefined && alert !== undefined && alert !== "info") {
    // warning/error
    status = "alert";
  } else if (
    (active === undefined || activeDeployment === null) &&
    (alert === undefined || alert === "info")
  ) {
    // Inactive status
    status = "inactive";
  } else if (
    (active === undefined || activeDeployment === null) &&
    alert !== undefined &&
    alert !== "info"
  ) {
    // inactive with warning/error
    status = "inactive alert";
  } else {
    // unknown fallback state
    status = null;
  }

  const iconStyle = { fill: theme.palette.status.icons };
  const iconTitle = iconConfig[status].title;
  const statusIcon = iconConfig[status].icon;

  return (
    <Tooltip
      title={iconTitle}
      style={iconStyle}
    >
      {statusIcon}
    </Tooltip>
  );
}

export function CommandTypeIcon({ type, colorStyle = "colors" }) {
  const theme = useTheme();

  const commandTypeColors = {
    start: theme.palette.status.ok,
    stop: theme.palette.status.fail
  };

  const commandTypeBlack = {
    start: theme.palette.status.icons,
    stop: theme.palette.status.icons
  };

  const colorConfig = {
    black: commandTypeBlack,
    colors: commandTypeColors
  };

  const commandTypeIcons = {
    start: {
      title: "Set to active",
      icon: <PlayCircleFilled />
    },
    stop: {
      title: "Set to inactive",
      icon: <PauseCircleFilled />
    }
  };

  const iconStyle = { fill: colorConfig[colorStyle][type.toLowerCase()] };
  const iconTitle = commandTypeIcons[type.toLowerCase()].title;
  const statusIcon = commandTypeIcons[type.toLowerCase()].icon;

  return (
    <Tooltip
      title={iconTitle}
      style={iconStyle}
    >
      {statusIcon}
    </Tooltip>
  );
}
