import React from "react";
import { Tooltip, useTheme } from "@material-ui/core";
import {
  Brightness1,
  ErrorOutline,
  Error,
  RadioButtonUnchecked,
  HelpOutline
} from "@material-ui/icons";

export function HostStatusIcon({ host }) {
  const theme = useTheme();

  let { status, alert, alerts } = host;

  const iconConfig = {
    available: {
      title: "Active",
      icon: <Brightness1 />
    },
    alert: {
      title: "Alert",
      icon: <Error />
    },
    inactive: {
      title: "Inactive",
      icon: <RadioButtonUnchecked />
    },
    "inactive alert": {
      title: "Alert",
      icon: <ErrorOutline />
    },
    null: {
      title: "Unknown",
      icon: <HelpOutline />
    }
  };

  let state = null;
  status = status?.toLowerCase();

  if (typeof alerts === "object") alert = alerts?.[0]?.type;

  alert = alert?.toLowerCase();

  if (status === "available" && (alert === undefined || alert === "info")) {
    // Available status / no error or warning
    state = "available";
  } else if (
    status === "available" &&
    (alert === "warning" || alert === "error")
  ) {
    // Available status / with error or warning
    state = "alert";
  } else if (
    status === "unreachable" &&
    (alert === undefined || alert === "info")
  ) {
    // Unreachable status / no error or warning
    state = "inactive";
  } else if (
    status === "unreachable" &&
    (alert === "warning" || alert === "error")
  ) {
    // Unreachable status / with error or warning
    state = "inactive alert";
  } else {
    // unknown fallback state
    state = null;
  }

  const iconStyle = { fill: theme.palette.status.icons };
  const iconTitle = iconConfig[state].title;
  const statusIcon = iconConfig[state].icon;

  return (
    <Tooltip
      title={iconTitle}
      style={iconStyle}
    >
      {statusIcon}
    </Tooltip>
  );
}
